#[non_exhaustive]pub struct AccessControlEntryStruct {
pub privilege: AccessControlEntryPrivilegeEnum,
pub auth_mode: AccessControlEntryAuthModeEnum,
pub subjects: Nullable<Vec<u64>>,
pub targets: Nullable<Vec<AccessControlTargetStruct>>,
pub fabric_index: u8,
}Expand description
AccessControlEntryStruct struct.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.privilege: AccessControlEntryPrivilegeEnumField Privilege (tag 1).
auth_mode: AccessControlEntryAuthModeEnumField AuthMode (tag 2).
subjects: Nullable<Vec<u64>>Field Subjects (tag 3).
targets: Nullable<Vec<AccessControlTargetStruct>>Field Targets (tag 4).
fabric_index: u8Field FabricIndex (tag 254).
Implementations
Sourceimpl AccessControlEntryStruct
impl AccessControlEntryStruct
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.