#[non_exhaustive]pub struct AccessRestrictionEntryStruct {
pub endpoint: u16,
pub cluster: u32,
pub restrictions: Vec<AccessRestrictionStruct>,
pub fabric_index: u8,
}Expand description
AccessRestrictionEntryStruct struct.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.endpoint: u16Field Endpoint (tag 0).
cluster: u32Field Cluster (tag 1).
restrictions: Vec<AccessRestrictionStruct>Field Restrictions (tag 2).
fabric_index: u8Field FabricIndex (tag 254).
Implementations
Sourceimpl AccessRestrictionEntryStruct
impl AccessRestrictionEntryStruct
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.