pub struct AccessRestrictionStruct {
pub type: AccessRestrictionTypeEnum,
pub id: Nullable<u32>,
}Expand description
AccessRestrictionStruct struct.
Fields
type: AccessRestrictionTypeEnumField Type (tag 0).
id: Nullable<u32>Field Id (tag 1).
Implementations
Sourceimpl AccessRestrictionStruct
impl AccessRestrictionStruct
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.
Sourcepub fn write_fields(&self, w: &mut TlvWriter<'_>)
pub fn write_fields(&self, w: &mut TlvWriter<'_>)
Write this struct’s fields into an already-open container.