pub struct CommissioningAccessRestrictionEntryStruct {
pub endpoint: u16,
pub cluster: u32,
pub restrictions: Vec<AccessRestrictionStruct>,
}Expand description
CommissioningAccessRestrictionEntryStruct struct.
Fields
endpoint: u16Field Endpoint (tag 0).
cluster: u32Field Cluster (tag 1).
restrictions: Vec<AccessRestrictionStruct>Field Restrictions (tag 2).
Implementations
Sourceimpl CommissioningAccessRestrictionEntryStruct
impl CommissioningAccessRestrictionEntryStruct
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.
Sourcepub fn write_fields(&self, w: &mut TlvWriter<'_>)
pub fn write_fields(&self, w: &mut TlvWriter<'_>)
Write this struct’s fields into an already-open container.