#[non_exhaustive]pub struct TargetStruct {
pub node: Option<u64>,
pub group: Option<u16>,
pub endpoint: Option<u16>,
pub cluster: Option<u32>,
pub fabric_index: u8,
}Expand description
TargetStruct struct.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.node: Option<u64>Field Node (tag 1).
group: Option<u16>Field Group (tag 2).
endpoint: Option<u16>Field Endpoint (tag 3).
cluster: Option<u32>Field Cluster (tag 4).
fabric_index: u8Field FabricIndex (tag 254).
Implementations
Sourceimpl TargetStruct
impl TargetStruct
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.
Sourcepub fn write_fields(&self, w: &mut TlvWriter<'_>)
pub fn write_fields(&self, w: &mut TlvWriter<'_>)
Write this struct’s fields into an already-open container.