DeviceTypeStruct

Struct DeviceTypeStruct 

#[non_exhaustive]
pub struct DeviceTypeStruct { pub device_type: u32, pub revision: u16, }
DeviceTypeStruct struct.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
device_type: u32

Field DeviceType (tag 0).

revision: u16

Field Revision (tag 1).

Implementations

Source

impl DeviceTypeStruct

pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>

Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).

Errors

Returns ClusterError on a malformed structure or missing required field.

pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>

Decode from a standalone anonymous TLV structure.

Errors

Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.

pub fn write_fields(&self, w: &mut TlvWriter<'_>)

Write this struct’s fields into an already-open container.

pub fn encode(&self) -> Vec<u8>

Encode as a standalone anonymous TLV structure.