#[non_exhaustive]pub struct GetCredentialStatusResponse {
pub credential_exists: bool,
pub user_index: Nullable<u16>,
pub creator_fabric_index: Nullable<u8>,
pub last_modified_fabric_index: Nullable<u8>,
pub next_credential_index: Option<Nullable<u16>>,
pub credential_data: Option<Nullable<Vec<u8>>>,
}Expand description
Decoded GetCredentialStatusResponse payload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.credential_exists: boolField CredentialExists (tag 0).
user_index: Nullable<u16>Field UserIndex (tag 1).
creator_fabric_index: Nullable<u8>Field CreatorFabricIndex (tag 2).
last_modified_fabric_index: Nullable<u8>Field LastModifiedFabricIndex (tag 3).
next_credential_index: Option<Nullable<u16>>Field NextCredentialIndex (tag 4).
credential_data: Option<Nullable<Vec<u8>>>Field CredentialData (tag 5).
Implementations
Sourceimpl GetCredentialStatusResponse
impl GetCredentialStatusResponse
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.