#[non_exhaustive]pub struct GetWeekDayScheduleResponse {
pub week_day_index: u8,
pub user_index: u16,
pub status: u8,
pub days_mask: Option<DaysMaskBitmap>,
pub start_hour: Option<u8>,
pub start_minute: Option<u8>,
pub end_hour: Option<u8>,
pub end_minute: Option<u8>,
}Expand description
Decoded GetWeekDayScheduleResponse payload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.week_day_index: u8Field WeekDayIndex (tag 0).
user_index: u16Field UserIndex (tag 1).
status: u8Field Status (tag 2).
days_mask: Option<DaysMaskBitmap>Field DaysMask (tag 3).
start_hour: Option<u8>Field StartHour (tag 4).
start_minute: Option<u8>Field StartMinute (tag 5).
end_hour: Option<u8>Field EndHour (tag 6).
end_minute: Option<u8>Field EndMinute (tag 7).
Implementations
Sourceimpl GetWeekDayScheduleResponse
impl GetWeekDayScheduleResponse
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.