#[non_exhaustive]pub struct MeasurementRangeStruct {
pub measurement_type: MeasurementTypeEnum,
pub min: i64,
pub max: i64,
pub start_timestamp: Option<u32>,
pub end_timestamp: Option<u32>,
pub min_timestamp: Option<u32>,
pub max_timestamp: Option<u32>,
pub start_systime: Option<u64>,
pub end_systime: Option<u64>,
pub min_systime: Option<u64>,
pub max_systime: Option<u64>,
}Expand description
MeasurementRangeStruct struct.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.measurement_type: MeasurementTypeEnumField MeasurementType (tag 0).
min: i64Field Min (tag 1).
max: i64Field Max (tag 2).
start_timestamp: Option<u32>Field StartTimestamp (tag 3).
end_timestamp: Option<u32>Field EndTimestamp (tag 4).
min_timestamp: Option<u32>Field MinTimestamp (tag 5).
max_timestamp: Option<u32>Field MaxTimestamp (tag 6).
start_systime: Option<u64>Field StartSystime (tag 7).
end_systime: Option<u64>Field EndSystime (tag 8).
min_systime: Option<u64>Field MinSystime (tag 9).
max_systime: Option<u64>Field MaxSystime (tag 10).
Implementations
Sourceimpl MeasurementRangeStruct
impl MeasurementRangeStruct
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.
Sourcepub fn write_fields(&self, w: &mut TlvWriter<'_>)
pub fn write_fields(&self, w: &mut TlvWriter<'_>)
Write this struct’s fields into an already-open container.