#[non_exhaustive]pub struct NetworkInterface {
pub name: String,
pub is_operational: bool,
pub off_premise_services_reachable_i_pv4: Nullable<bool>,
pub off_premise_services_reachable_i_pv6: Nullable<bool>,
pub hardware_address: Vec<u8>,
pub i_pv4_addresses: Vec<Vec<u8>>,
pub i_pv6_addresses: Vec<Vec<u8>>,
pub type: InterfaceTypeEnum,
}Expand description
NetworkInterface struct.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringField Name (tag 0).
is_operational: boolField IsOperational (tag 1).
off_premise_services_reachable_i_pv4: Nullable<bool>Field OffPremiseServicesReachableIPv4 (tag 2).
off_premise_services_reachable_i_pv6: Nullable<bool>Field OffPremiseServicesReachableIPv6 (tag 3).
hardware_address: Vec<u8>Field HardwareAddress (tag 4).
i_pv4_addresses: Vec<Vec<u8>>Field IPv4Addresses (tag 5).
i_pv6_addresses: Vec<Vec<u8>>Field IPv6Addresses (tag 6).
type: InterfaceTypeEnumField Type (tag 7).
Implementations
Sourceimpl NetworkInterface
impl NetworkInterface
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.