#[non_exhaustive]pub struct TimeSnapshotResponse {
pub system_time_ms: u64,
pub posix_time_ms: Nullable<u64>,
}Expand description
Decoded TimeSnapshotResponse payload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.system_time_ms: u64Field SystemTimeMs (tag 0).
posix_time_ms: Nullable<u64>Field PosixTimeMs (tag 1).
Implementations
Sourceimpl TimeSnapshotResponse
impl TimeSnapshotResponse
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.