#[non_exhaustive]pub struct GetGroupMembershipResponse {
pub capacity: Nullable<u8>,
pub group_list: Vec<u16>,
}Expand description
Decoded GetGroupMembershipResponse payload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.capacity: Nullable<u8>Field Capacity (tag 0).
group_list: Vec<u16>Field GroupList (tag 1).
Implementations
Sourceimpl GetGroupMembershipResponse
impl GetGroupMembershipResponse
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.