pub fn encode_options(value: OptionsBitmap) -> Vec<u8> ⓘExpand description
Encode the Options attribute value as a standalone TLV element.
pub fn encode_options(value: OptionsBitmap) -> Vec<u8> ⓘEncode the Options attribute value as a standalone TLV element.