#[non_exhaustive]pub struct SignVidVerificationResponse {
pub fabric_index: u8,
pub fabric_binding_version: u8,
pub signature: Vec<u8>,
}Expand description
Decoded SignVidVerificationResponse payload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fabric_index: u8Field FabricIndex (tag 0).
fabric_binding_version: u8Field FabricBindingVersion (tag 1).
signature: Vec<u8>Field Signature (tag 2).
Implementations
Sourceimpl SignVidVerificationResponse
impl SignVidVerificationResponse
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.