#[non_exhaustive]pub struct ApplyUpdateResponse {
pub action: ApplyUpdateActionEnum,
pub delayed_action_time: u32,
}Expand description
Decoded ApplyUpdateResponse payload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.action: ApplyUpdateActionEnumField Action (tag 0).
delayed_action_time: u32Field DelayedActionTime (tag 1).
Implementations
Sourceimpl ApplyUpdateResponse
impl ApplyUpdateResponse
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.