QueryImageResponse

Struct QueryImageResponse 

#[non_exhaustive]
pub struct QueryImageResponse { pub status: StatusEnum, pub delayed_action_time: Option<u32>, pub image_uri: Option<String>, pub software_version: Option<u32>, pub software_version_string: Option<String>, pub update_token: Option<Vec<u8>>, pub user_consent_needed: Option<bool>, pub metadata_for_requestor: Option<Vec<u8>>, }
Decoded QueryImageResponse payload.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
status: StatusEnum

Field Status (tag 0).

delayed_action_time: Option<u32>

Field DelayedActionTime (tag 1).

image_uri: Option<String>

Field ImageUri (tag 2).

software_version: Option<u32>

Field SoftwareVersion (tag 3).

software_version_string: Option<String>

Field SoftwareVersionString (tag 4).

update_token: Option<Vec<u8>>

Field UpdateToken (tag 5).

user_consent_needed: Option<bool>

Field UserConsentNeeded (tag 6).

metadata_for_requestor: Option<Vec<u8>>

Field MetadataForRequestor (tag 7).

Implementations

Source

impl QueryImageResponse

pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>

Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).

Errors

Returns ClusterError on a malformed structure or missing required field.

pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>

Decode from a standalone anonymous TLV structure.

Errors

Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.