#[non_exhaustive]pub struct PresetStruct {
pub preset_handle: Nullable<Vec<u8>>,
pub preset_scenario: PresetScenarioEnum,
pub name: Option<Nullable<String>>,
pub cooling_setpoint: Option<i16>,
pub heating_setpoint: Option<i16>,
pub built_in: Nullable<bool>,
}Expand description
PresetStruct struct.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.preset_handle: Nullable<Vec<u8>>Field PresetHandle (tag 0).
preset_scenario: PresetScenarioEnumField PresetScenario (tag 1).
name: Option<Nullable<String>>Field Name (tag 2).
cooling_setpoint: Option<i16>Field CoolingSetpoint (tag 3).
heating_setpoint: Option<i16>Field HeatingSetpoint (tag 4).
built_in: Nullable<bool>Field BuiltIn (tag 5).
Implementations
Sourceimpl PresetStruct
impl PresetStruct
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.
Sourcepub fn write_fields(&self, w: &mut TlvWriter<'_>)
pub fn write_fields(&self, w: &mut TlvWriter<'_>)
Write this struct’s fields into an already-open container.