#[non_exhaustive]pub struct PresetTypeStruct {
pub preset_scenario: PresetScenarioEnum,
pub number_of_presets: u8,
pub preset_type_features: PresetTypeFeaturesBitmap,
}Expand description
PresetTypeStruct struct.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.preset_scenario: PresetScenarioEnumField PresetScenario (tag 0).
number_of_presets: u8Field NumberOfPresets (tag 1).
preset_type_features: PresetTypeFeaturesBitmapField PresetTypeFeatures (tag 2).
Implementations
Sourceimpl PresetTypeStruct
impl PresetTypeStruct
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.
Sourcepub fn write_fields(&self, w: &mut TlvWriter<'_>)
pub fn write_fields(&self, w: &mut TlvWriter<'_>)
Write this struct’s fields into an already-open container.