#[non_exhaustive]pub struct ScheduleStruct {
pub schedule_handle: Nullable<Vec<u8>>,
pub system_mode: SystemModeEnum,
pub name: Option<String>,
pub preset_handle: Option<Vec<u8>>,
pub transitions: Vec<ScheduleTransitionStruct>,
pub built_in: Nullable<bool>,
}Expand description
ScheduleStruct struct.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.schedule_handle: Nullable<Vec<u8>>Field ScheduleHandle (tag 0).
system_mode: SystemModeEnumField SystemMode (tag 1).
name: Option<String>Field Name (tag 2).
preset_handle: Option<Vec<u8>>Field PresetHandle (tag 3).
transitions: Vec<ScheduleTransitionStruct>Field Transitions (tag 4).
built_in: Nullable<bool>Field BuiltIn (tag 5).
Implementations
Sourceimpl ScheduleStruct
impl ScheduleStruct
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.