#[non_exhaustive]pub struct ScheduleTransitionStruct {
pub day_of_week: ScheduleDayOfWeekBitmap,
pub transition_time: u16,
pub preset_handle: Option<Vec<u8>>,
pub system_mode: Option<SystemModeEnum>,
pub cooling_setpoint: Option<i16>,
pub heating_setpoint: Option<i16>,
}Expand description
ScheduleTransitionStruct struct.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.day_of_week: ScheduleDayOfWeekBitmapField DayOfWeek (tag 0).
transition_time: u16Field TransitionTime (tag 1).
preset_handle: Option<Vec<u8>>Field PresetHandle (tag 2).
system_mode: Option<SystemModeEnum>Field SystemMode (tag 3).
cooling_setpoint: Option<i16>Field CoolingSetpoint (tag 4).
heating_setpoint: Option<i16>Field HeatingSetpoint (tag 5).
Implementations
Sourceimpl ScheduleTransitionStruct
impl ScheduleTransitionStruct
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.
Sourcepub fn write_fields(&self, w: &mut TlvWriter<'_>)
pub fn write_fields(&self, w: &mut TlvWriter<'_>)
Write this struct’s fields into an already-open container.