pub struct DSTOffsetStruct {
pub offset: i32,
pub valid_starting: u64,
pub valid_until: Nullable<u64>,
}Expand description
DSTOffsetStruct struct.
Fields
offset: i32Field Offset (tag 0).
valid_starting: u64Field ValidStarting (tag 1).
valid_until: Nullable<u64>Field ValidUntil (tag 2).
Implementations
Sourceimpl DSTOffsetStruct
impl DSTOffsetStruct
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.
Sourcepub fn write_fields(&self, w: &mut TlvWriter<'_>)
pub fn write_fields(&self, w: &mut TlvWriter<'_>)
Write this struct’s fields into an already-open container.