pub struct FabricScopedTrustedTimeSourceStruct {
pub node_id: u64,
pub endpoint: u16,
}Expand description
FabricScopedTrustedTimeSourceStruct struct.
Fields
node_id: u64Field NodeId (tag 0).
endpoint: u16Field Endpoint (tag 1).
Implementations
Sourceimpl FabricScopedTrustedTimeSourceStruct
impl FabricScopedTrustedTimeSourceStruct
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.
Sourcepub fn write_fields(&self, w: &mut TlvWriter<'_>)
pub fn write_fields(&self, w: &mut TlvWriter<'_>)
Write this struct’s fields into an already-open container.