pub struct TimeZoneStruct {
pub offset: i32,
pub valid_at: u64,
pub name: Option<String>,
}Expand description
TimeZoneStruct struct.
Fields
offset: i32Field Offset (tag 0).
valid_at: u64Field ValidAt (tag 1).
name: Option<String>Field Name (tag 2).
Implementations
Sourceimpl TimeZoneStruct
impl TimeZoneStruct
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.
Sourcepub fn write_fields(&self, w: &mut TlvWriter<'_>)
pub fn write_fields(&self, w: &mut TlvWriter<'_>)
Write this struct’s fields into an already-open container.