pub struct SafetyStatusBitmap(/* private fields */);Expand description
SafetyStatusBitmap (map16).
Implementations
Sourceimpl SafetyStatusBitmap
impl SafetyStatusBitmap
Sourcepub const REMOTE_LOCKOUT: Self
pub const REMOTE_LOCKOUT: Self
RemoteLockout.
Sourcepub const TAMPER_DETECTION: Self
pub const TAMPER_DETECTION: Self
TamperDetection.
Sourcepub const FAILED_COMMUNICATION: Self
pub const FAILED_COMMUNICATION: Self
FailedCommunication.
Sourcepub const POSITION_FAILURE: Self
pub const POSITION_FAILURE: Self
PositionFailure.
Sourcepub const THERMAL_PROTECTION: Self
pub const THERMAL_PROTECTION: Self
ThermalProtection.
Sourcepub const OBSTACLE_DETECTED: Self
pub const OBSTACLE_DETECTED: Self
ObstacleDetected.
Sourcepub const STOP_INPUT: Self
pub const STOP_INPUT: Self
StopInput.
Sourcepub const MOTOR_JAMMED: Self
pub const MOTOR_JAMMED: Self
MotorJammed.
Sourcepub const HARDWARE_FAILURE: Self
pub const HARDWARE_FAILURE: Self
HardwareFailure.
Sourcepub const MANUAL_OPERATION: Self
pub const MANUAL_OPERATION: Self
ManualOperation.
Sourcepub const PROTECTION: Self
pub const PROTECTION: Self
Protection.
Sourceimpl SafetyStatusBitmap
impl SafetyStatusBitmap
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl SafetyStatusBitmap
impl SafetyStatusBitmap
Sourcepub const fn iter(&self) -> Iter<SafetyStatusBitmap> ⓘ
pub const fn iter(&self) -> Iter<SafetyStatusBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SafetyStatusBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<SafetyStatusBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.