pub struct GroupKeySetStruct {
pub group_key_set_id: u16,
pub group_key_security_policy: GroupKeySecurityPolicyEnum,
pub epoch_key0: Nullable<Vec<u8>>,
pub epoch_start_time0: Nullable<u64>,
pub epoch_key1: Nullable<Vec<u8>>,
pub epoch_start_time1: Nullable<u64>,
pub epoch_key2: Nullable<Vec<u8>>,
pub epoch_start_time2: Nullable<u64>,
pub group_key_multicast_policy: Option<GroupKeyMulticastPolicyEnum>,
pub fabric_index: Option<u8>,
}Expand description
GroupKeySetStruct struct.
Fields
group_key_set_id: u16Field GroupKeySetId (tag 0).
group_key_security_policy: GroupKeySecurityPolicyEnumField GroupKeySecurityPolicy (tag 1).
epoch_key0: Nullable<Vec<u8>>Field EpochKey0 (tag 2).
epoch_start_time0: Nullable<u64>Field EpochStartTime0 (tag 3).
epoch_key1: Nullable<Vec<u8>>Field EpochKey1 (tag 4).
epoch_start_time1: Nullable<u64>Field EpochStartTime1 (tag 5).
epoch_key2: Nullable<Vec<u8>>Field EpochKey2 (tag 6).
epoch_start_time2: Nullable<u64>Field EpochStartTime2 (tag 7).
group_key_multicast_policy: Option<GroupKeyMulticastPolicyEnum>Field GroupKeyMulticastPolicy (tag 8).
fabric_index: Option<u8>Field FabricIndex (tag 254).
Implementations
Sourceimpl GroupKeySetStruct
impl GroupKeySetStruct
Sourcepub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
pub fn decode_from(r: &mut TlvReader<'_>) -> Result<Self, ClusterError>
Decode the fields of an already-opened anonymous structure (reader positioned after the struct start; consumes to its end).
Errors
Returns ClusterError on a malformed structure or missing required field.
Sourcepub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
pub fn decode(tlv: &[u8]) -> Result<Self, ClusterError>
Decode from a standalone anonymous TLV structure.
Errors
Returns ClusterError if the bytes are not an anonymous structure or a field is malformed.
Sourcepub fn write_fields(&self, w: &mut TlvWriter<'_>)
pub fn write_fields(&self, w: &mut TlvWriter<'_>)
Write this struct’s fields into an already-open container.